.. _docstring_example-name:

!!!!!!!!!!!!!!!!!
docstring_example
!!!!!!!!!!!!!!!!!

.. meta::
   :keywords: docstring_example, docstring

.. index:: docstring_example, docstring

.. _docstring_example-title:

Docstring Example
#################

.. contents::
   :local:

.. meta::
   :keywords: discussion

.. index:: discussion

.. _docstring_example@Discussion:

Discussion
**********
This example demonstrates using a python docstring to document a function.
see :ref:`indent_example@Python Docstring`
for an example of an indented docstring.

.. _docstring_example@This Example File:

This Example File
*****************

.. literalinclude:: ../../example/docstring.py
   :language: py
